@@ -4,13 +4,13 @@ import json
 import subprocess
 
 from six.moves.urllib.parse import urlencode
+from time import sleep
 import enum
 
 import requests
 import six
 import rapyuta_io
 
-from rapyuta_io.clients.deployment import DeploymentPhaseConstants, Deployment
 from rapyuta_io.clients.model import TopicsStatus, DeviceConfig, Label, Metric, LogUploadStatus, \
     LogUploads, SharedURL
 from rapyuta_io.utils import ObjDict, RestClient, ParameterMissingException, \
@@ -23,6 +23,7 @@ from rapyuta_io.utils.settings import *
 from rapyuta_io.utils.utils import create_auth_header, get_error, get_api_response_data, \
     validate_key_value, response_validator, is_true
 from rapyuta_io.utils.partials import PartialMixin
+from rapyuta_io.utils.pollers import RefreshPollerMixin
 
 DEVICE_API_ERRORS = {
     400: ParameterMissingException,
@@ -218,7 +219,7 @@ class DevicePythonVersion(str, enum.Enum):
     PYTHON3 = '3'
 
 
-class Device(PartialMixin, ObjDict):
+class Device(PartialMixin, RefreshPollerMixin, ObjDict):
     """
     Device class represents a device. Member variables of the class represent the
     properties of device. \n
@@ -253,7 +254,8 @@ class Device(PartialMixin, ObjDict):
 
     def __init__(self, name, runtime=None, runtime_docker=False, runtime_preinstalled=False, ros_distro=None,
                  rosbag_mount_path=None,
-                 ros_workspace=None, description=None, python_version=DevicePythonVersion.PYTHON2):
+                 ros_workspace=None, description=None, python_version=DevicePythonVersion.PYTHON2,
+                 config_variables=None, labels=None):
         self.validate(name, runtime, runtime_docker, runtime_preinstalled, ros_distro, rosbag_mount_path, ros_workspace,
                       description, python_version)
         self.name = name
@@ -272,6 +274,8 @@ class Device(PartialMixin, ObjDict):
         self._ros_workspace = ros_workspace
         self.description = description
         self.python_version = python_version
+        self.config_variables = config_variables or {}
+        self.labels = labels or {}
 
     @staticmethod
     def validate(name, runtime, runtime_docker, runtime_preinstalled, ros_distro, rosbag_mount_path,
@@ -289,11 +293,11 @@ class Device(PartialMixin, ObjDict):
             raise InvalidParameterException(
                 'python_version must be one of rapyuta.io.client.device.DevicePythonVersion')
         if ros_distro is not None and (
-                ros_distro not in list(rapyuta_io.clients.package.ROSDistro.__members__.values())):
+                ros_distro not in list(ROSDistro.__members__.values())):
             raise InvalidParameterException('ros_distro must be one of rapyuta_io.clients.package.ROSDistro')
-        if runtime_preinstalled and ros_distro == rapyuta_io.clients.package.ROSDistro.NOETIC:
+        if runtime_preinstalled and ros_distro == ROSDistro.NOETIC:
             raise InvalidParameterException('preinstalled runtime does not support noetic ros_distro yet')
-        if ros_distro == rapyuta_io.clients.package.ROSDistro.NOETIC and python_version == DevicePythonVersion.PYTHON2:
+        if ros_distro == ROSDistro.NOETIC and python_version == DevicePythonVersion.PYTHON2:
             raise InvalidParameterException('noetic ros_distro not supported on python_version 2')
         if rosbag_mount_path is not None and not isinstance(rosbag_mount_path, six.string_types):
             raise InvalidParameterException('rosbag_mount_path must be of type string')
@@ -320,6 +324,8 @@ class Device(PartialMixin, ObjDict):
                       '_ros_workspace']:
             if getattr(self, field):
                 device['config_variables'][field[1:]] = getattr(self, field)
+        device['config_variables'].update(self.config_variables)
+        device['labels'] = self.labels
         return device
 
     @classmethod
@@ -339,8 +345,6 @@ class Device(PartialMixin, ObjDict):
             obj.config_variables = [DeviceConfig(to_objdict(config)) for config in obj.config_variables]
         if obj.labels:
             obj.labels = [Label(to_objdict(label)) for label in obj.labels]
-        if hasattr(obj, 'deployments') and obj.deployments:
-            obj.deployments = [Deployment(to_objdict(deployment)) for deployment in obj.deployments]
         return obj
 
     def is_online(self):
@@ -348,6 +352,9 @@ class Device(PartialMixin, ObjDict):
             return True
         return False
 
+    def is_ready(self):
+        return self.is_online()
+
     def get_runtime(self):
         """
         Get the device runtime
@@ -561,7 +568,44 @@ class Device(PartialMixin, ObjDict):
         if response.status_code == requests.codes.BAD_REQUEST:
             raise ParameterMissingException(get_error(response.text))
         execution_result = get_api_response_data(response)
-        return execution_result[self.uuid]
+        if not command.bg:
+            return execution_result[self.uuid]
+        jid = execution_result.get('jid')
+        if not jid:
+            raise ValueError("Job ID not found in the response")
+        return self.fetch_command_result(jid, [self.uuid], timeout=command.timeout)
+
+    def fetch_command_result(self, jid: str, deviceids: list, timeout: int):
+        """
+        Fetch the result of the command execution using the job ID (jid) and the first device ID from the list.
+        Args:
+            jobid (str): The job ID of the executed command.
+            deviceids (list): A list of device IDs on which the command was executed.
+            timeout (int): The maximum time to wait for the result (in seconds). Default is 300 seconds.
+        Returns:
+            dict: The result of the command execution.
+        Raises:
+            TimeoutError: If the result is not available within the timeout period.
+            APIError: If the API returns an error.
+        """
+
+        if not deviceids or not isinstance(deviceids, list):
+            raise ValueError("Device IDs must be provided as a non-empty list.")
+        url = self._device_api_host + DEVICE_COMMAND_API_PATH + "jobid"
+        payload = {
+            "jid": jid,
+            "device_id": deviceids[0]
+        }
+        total_time_waited = 0
+        wait_interval = 10
+        while total_time_waited < timeout:
+            response = self._execute_api(url, HttpMethod.POST, payload)
+            if response.status_code == requests.codes.OK:
+                result = get_api_response_data(response)
+                return result[deviceids[0]]
+            sleep(wait_interval)
+            total_time_waited += wait_interval
+        raise TimeoutError(f"Command result not available after {timeout} seconds")
 
     def get_config_variables(self):
         """
@@ -1391,3 +1435,43 @@ class Device(PartialMixin, ObjDict):
         if response.status_code == requests.codes.BAD_REQUEST:
             raise DeploymentRunningException()
         get_api_response_data(response)
+
+
+class ROSDistro(str, enum.Enum):
+    """
+    Enumeration variables for the Supported ROS Distros. ROS Distro may be one of: \n
+    ROSDistro.KINETIC ('kinetic') \n
+    ROSDistro.MELODIC ('melodic') \n
+    ROSDistro.NOETIC ('noetic') \n
+    """
+
+    def __str__(self):
+        return str(self.value)
+
+    KINETIC = 'kinetic'
+    MELODIC = 'melodic'
+    NOETIC = 'noetic'
+
+
+class DeploymentPhaseConstants(str, enum.Enum):
+    """
+    Enumeration variables for the deployment phase
+
+    Deployment phase can be any of the following types \n
+    DeploymentPhaseConstants.INPROGRESS \n
+    DeploymentPhaseConstants.PROVISIONING \n
+    DeploymentPhaseConstants.SUCCEEDED \n
+    DeploymentPhaseConstants.FAILED_TO_START \n
+    DeploymentPhaseConstants.PARTIALLY_DEPROVISIONED \n
+    DeploymentPhaseConstants.DEPLOYMENT_STOPPED \n
+    """
+
+    def __str__(self):
+        return str(self.value)
+
+    INPROGRESS = 'In progress'
+    PROVISIONING = 'Provisioning'
+    SUCCEEDED = 'Succeeded'
+    FAILED_TO_START = 'Failed to start'
+    PARTIALLY_DEPROVISIONED = 'Partially deprovisioned'
+    DEPLOYMENT_STOPPED = 'Deployment stopped'
