@@ -1,15 +1,13 @@
 from __future__ import absolute_import
-import re
 
 import enum
+import re
 
 import six
 
 from rapyuta_io.clients.organization import Organization
-from rapyuta_io.utils import RestClient, InvalidParameterException
+from rapyuta_io.utils import InvalidParameterException
 from rapyuta_io.utils.object_converter import ObjBase, list_field, nested_field
-from rapyuta_io.utils.rest_client import HttpMethod
-from rapyuta_io.utils.utils import create_auth_header, get_api_response_data
 
 project_name_regex = re.compile('^[a-z0-9-]{3,15}$')
 
@@ -18,8 +16,6 @@ class Project(ObjBase):
     """
     Project is an organizational unit and all the resources must belong to a Project.
 
-    :ivar id: id of the Project
-    :vartype id: int
     :ivar guid: guid of the Project
     :vartype guid: str
     :ivar created_at: creation time of the Project
@@ -33,11 +29,7 @@ class Project(ObjBase):
     :ivar creator: GUID of the User that created the Project
     :vartype creator: str
     :ivar users: Users that have access to the Project
-    :vartype users:   list(:py:class:`~rapyuta_io.clients.project.User`)
-    :ivar organization: Organization that the project belongs to
-    :vartype organization: :py:class:`~rapyuta_io.clients.organization.Organization`
     """
-    PROJECT_PATH = '/api/project'
 
     def __init__(self, name, organization_guid=None):
         self.validate(name, organization_guid)
@@ -55,27 +47,6 @@ class Project(ObjBase):
             setattr(org, 'guid', organization_guid)
         self.organization = org
 
-    def get_deserialize_map(self):
-        return {
-            'id': 'ID',
-            'guid': 'guid',
-            'created_at': 'CreatedAt',
-            'updated_at': 'UpdatedAt',
-            'deleted_at': 'DeletedAt',
-            'name': 'name',
-            'creator': 'creator',
-            'users': list_field('users', User),
-            'organization': nested_field('organization', Organization)
-        }
-
-    def get_serialize_map(self):
-        serialized_project = {
-            'name': 'name',
-        }
-        if self.organization is not None:
-            serialized_project['organization'] = 'organization'
-        return serialized_project
-
     @staticmethod
     def validate(name, organization_guid):
         if not isinstance(name, str):
@@ -88,27 +59,23 @@ class Project(ObjBase):
         if not project_name_regex.match(name):
             raise InvalidParameterException('name can have alphabets, numbers or - only')
 
-    def delete(self):
+    def get_deserialize_map(self):
+        return {
+            'guid': 'guid',
+            'created_at': 'createdAt',
+            'updated_at': 'updatedAt',
+            'deleted_at': 'deletedAt',
+            'name': 'name',
+            'creator': 'creatorGUID',
+        }
 
-        """
-        Delete the project using the project object.
-
-        Following example demonstrates how to delete a project using project object:
-
-        >>> from rapyuta_io import Client
-        >>> client = Client(auth_token='auth_token', project='project_guid')
-        >>> project = client.get_project(guid='project-id')
-        >>> project.delete()
-
-        """
-
-        if not (hasattr(self, '_core_api_host') and hasattr(self, '_auth_token')):
-            raise InvalidParameterException('Project must be created first')
-        url = self._core_api_host + self.PROJECT_PATH + '/delete'
-        headers = create_auth_header(self._auth_token, self.guid)
-        payload = {'guid': self.guid}
-        response = RestClient(url).method(HttpMethod.DELETE).headers(headers).execute(payload)
-        get_api_response_data(response, parse_full=True)
+    def get_serialize_map(self):
+        serialized_project = {
+            'name': 'name',
+        }
+        if self.organization is not None:
+            serialized_project['organization'] = 'organization'
+        return serialized_project
 
 
 class User(ObjBase):
@@ -132,6 +99,7 @@ class User(ObjBase):
     :ivar organizations: List of organizations that the user is part of
     :vartype organizations:  list(:py:class:`~rapyuta_io.clients.organization.Organization`)
     """
+
     def __init__(self):
         self.guid = None
         self.first_name = None
